@@ -16,18 +16,14 @@ sub new {
 sub transform {
     my $self    = shift;
     my $key     = shift;
+    my $schema_key = shift;
     my $section = shift;
-
-    if (exists $section->{schema}->{$key}
-        and exists $section->{schema}->{$key}->{transformer}){
-
+    if (exists $section->{schema}{$schema_key}{transformer}){
         my $return_value;
         eval {
             local $SIG{__DIE__};
             $return_value =
-                $section->{schema}->{$key}->{transformer}
-                ->($section->{data}->{$key},$section->{data});
-
+                $section->{schema}{$schema_key}{transformer}($section->{data}{$key},$section->{data});
         };
         if (my $err = $@) {
             if (ref $err eq 'HASH' && defined $err->{msg}){
@@ -35,7 +31,7 @@ sub transform {
             }
             return "error transforming '$key': $err";
         }
-        $section->{data}->{$key} = $return_value;
+        $section->{data}{$key} = $return_value;
     }
     return undef;
 }
